==> openshift-model-6.7.2-sources.jar: io/fabric8/openshift/api/model/HelmChartRepositorySpecBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class HelmChartRepositorySpecBuilder extends HelmChartRepositorySpecFluentImpl<HelmChartRepositorySpecBuilder> implements VisitableBuilder<HelmChartRepositorySpec,HelmChartRepositorySpecBuilder>{
  public HelmChartRepositorySpecBuilder() {
    this(false);
  }
  public HelmChartRepositorySpecBuilder(Boolean validationEnabled) {
    this(new HelmChartRepositorySpec(), validationEnabled);
  }
  public HelmChartRepositorySpecBuilder(HelmChartRepositorySpecFluent<?> fluent) {
    this(fluent, false);
  }
  public HelmChartRepositorySpecBuilder(HelmChartRepositorySpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new HelmChartRepositorySpec(), validationEnabled);
  }
  public HelmChartRepositorySpecBuilder(HelmChartRepositorySpecFluent<?> fluent,HelmChartRepositorySpec instance) {
    this(fluent, instance, false);
  }
  public HelmChartRepositorySpecBuilder(HelmChartRepositorySpecFluent<?> fluent,HelmChartRepositorySpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withConnectionConfig(instance.getConnectionConfig());
      fluent.withDescription(instance.getDescription());
      fluent.withDisabled(instance.getDisabled());
      fluent.withName(instance.getName());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public HelmChartRepositorySpecBuilder(HelmChartRepositorySpec instance) {
    this(instance,false);
  }
  public HelmChartRepositorySpecBuilder(HelmChartRepositorySpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withConnectionConfig(instance.getConnectionConfig());
      this.withDescription(instance.getDescription());
      this.withDisabled(instance.getDisabled());
      this.withName(instance.getName());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  HelmChartRepositorySpecFluent<?> fluent;
  Boolean validationEnabled;
  public HelmChartRepositorySpec build() {
    HelmChartRepositorySpec buildable = new HelmChartRepositorySpec(fluent.getConnectionConfig(),fluent.getDescription(),fluent.getDisabled(),fluent.getName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-6.8.0-sources.jar: io/fabric8/openshift/api/model/HelmChartRepositorySpecBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class HelmChartRepositorySpecBuilder extends HelmChartRepositorySpecFluent<HelmChartRepositorySpecBuilder> implements VisitableBuilder<HelmChartRepositorySpec,HelmChartRepositorySpecBuilder>{
  public HelmChartRepositorySpecBuilder() {
    this(false);
  }
  public HelmChartRepositorySpecBuilder(Boolean validationEnabled) {
    this(new HelmChartRepositorySpec(), validationEnabled);
  }
  public HelmChartRepositorySpecBuilder(HelmChartRepositorySpecFluent<?> fluent) {
    this(fluent, false);
  }
  public HelmChartRepositorySpecBuilder(HelmChartRepositorySpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new HelmChartRepositorySpec(), validationEnabled);
  }
  public HelmChartRepositorySpecBuilder(HelmChartRepositorySpecFluent<?> fluent,HelmChartRepositorySpec instance) {
    this(fluent, instance, false);
  }
  public HelmChartRepositorySpecBuilder(HelmChartRepositorySpecFluent<?> fluent,HelmChartRepositorySpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new HelmChartRepositorySpec());

    if (instance != null) {
      fluent.withConnectionConfig(instance.getConnectionConfig());
      fluent.withDescription(instance.getDescription());
      fluent.withDisabled(instance.getDisabled());
      fluent.withName(instance.getName());
      fluent.withConnectionConfig(instance.getConnectionConfig());
      fluent.withDescription(instance.getDescription());
      fluent.withDisabled(instance.getDisabled());
      fluent.withName(instance.getName());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public HelmChartRepositorySpecBuilder(HelmChartRepositorySpec instance) {
    this(instance,false);
  }
  public HelmChartRepositorySpecBuilder(HelmChartRepositorySpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new HelmChartRepositorySpec());

    if (instance != null) {
      this.withConnectionConfig(instance.getConnectionConfig());
      this.withDescription(instance.getDescription());
      this.withDisabled(instance.getDisabled());
      this.withName(instance.getName());
      this.withConnectionConfig(instance.getConnectionConfig());
      this.withDescription(instance.getDescription());
      this.withDisabled(instance.getDisabled());
      this.withName(instance.getName());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  HelmChartRepositorySpecFluent<?> fluent;
  Boolean validationEnabled;
  public HelmChartRepositorySpec build() {
    HelmChartRepositorySpec buildable = new HelmChartRepositorySpec(fluent.buildConnectionConfig(),fluent.getDescription(),fluent.getDisabled(),fluent.getName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
